# VIVAL

Command line app to validate standard I/O applications on series of tests.

# Installation

## Using Pip

```bash
  $ pip install vival
```
## Manual

```bash
  $ git clone https://github.com/ViktorooReps/vival
  $ cd vival
  $ python setup.py install
```

# Usage

`vival <executable> -t <path/tests.txt>`
```bash
$ vival
```
